Class to draw stock charts
comparedDataSetslist of '>DataSet.
Properties of data sets selected for comparison.
dataSetslist of '>DataSet.
Each element must be a list of DataSet properties.
dataSetSelectorlist of '>DataSetSelector.
You can add it if you have more than one data set and want users
to be able to select/compare them.
mainDataSetpanelsperiodSelector'>PeriodSelector. You can add it if you want users to be able to enter date ranges or zoom chart with predefined period buttons.
themecharacter
typeequals "stock"
groupcharacter for synchronization
is_ts_modulelogicalOrMissing. Don't use. For rAmChartsTimeSeriesUI
listenerslist containining the listeners to add to the chart.
The list must be named as in the official API. Each element must be a character string.
otherPropertieslist
containing other avalaible properties not yet implemented in the package.
valuenumeric.
http://docs.amcharts.com/3/javascriptstockchart/AmStockChart