Learn R Programming

rAmCharts (version 2.0.3)

GaugeAxis-class: GaugeAxis class

Description

Creates an axis for AmAngularGaugeChart, multiple can be assigned.

Arguments

Slots

bands
list containing properties of one or several GaugeBand objects. Bands are used to draw color fills between specified values.
listeners
list containining the listeners to add to the chart. The list must be named as in the official API. Each element must be a character string.
otherProperties
list containing other avalaible properties not yet implemented in the package.
value
numeric.

Details

Run api("GaugeAxis") for more information and all avalaible properties.