Learn R Programming

rAmCharts (version 2.0.3)

GaugeBand-class: GaugeBand class

Description

Creates a band for a specified value range on the GaugeAxis. Multiple bands can be assigned to a single GaugeAxis.

Arguments

Slots

id
character. Unique id of a band.
listeners
list containining the listeners to add to the chart. The list must be named as in the official API. Each element must be a character string.
otherProperties
list containing other avalaible properties not yet implemented in the package.
value
numeric.

Details

Run api("GaugeBand") for more information and all avalaible properties.