Learn R Programming

rAmCharts (version 2.0.3)

Title-class: Title class

Description

Creates a title on above the chart, multiple can be assigned.

Arguments

Slots

text
character, title's text.
size
numeric, title's size.
listeners
list containining the listeners to add to the object. The list must be named as in the official API. Each element must be a character string. See examples for details.
otherProperties
list containing other avalaible properties not yet implemented in the package.
value
numeric.

Details

Run api("Title") for more informations and all avalaible properties.