GaugeBand-class: GaugeBand class
Description
Creates a band for a specified value range on the GaugeAxis.
Multiple bands can be assigned to a single GaugeAxis.
Slots
idcharacter. Unique id of a band. listenerslist containining the listeners to add to the chart.
The list must be named as in the official API. Each element must be a character string. otherPropertieslist
containing other avalaible properties not yet implemented in the package. valuenumeric.
Details
Run api("GaugeBand") for more information and all avalaible properties.