textcharacter, title's text.sizenumeric, title's size.listenerslist containining the listeners to add to the object.
The list must be named as in the official API. Each element must be a character string.
See examples for details.otherPropertieslist
containing other avalaible properties not yet implemented in the package.valuenumeric.api("Title") for more informations and all avalaible properties.